@@ -92,6 +92,12 @@ class LogHandle(object):
         while True:
             args = self.__read_pipe.recv()
 
+            while isinstance(args, list) and not args[0]:
+                args.remove(args[0])
+
+            if isinstance(args, list) and len(args) == 1 and isinstance(args[0], list):
+                args = args[0]
+
             if isinstance(args, dict) and 'command' in args.keys():
                 command = args['command']
                 del args['command']
@@ -103,10 +109,6 @@ class LogHandle(object):
             elif isinstance(args, list) and len(args) > 1:
                 command = args[0]
 
-                while not command:
-                    args.remove(args[0])
-                    command = args[0]
-
                 if command == 'gui_console':
                     self.__gui_console_set(*args)
                 elif command == 'write_to_log':
